#!/usr/bin/env python3
#
# Simple SMTP client for testing purposes.

import argparse
import email.parser
import email.policy
import re
import smtplib
import sys

ap = argparse.ArgumentParser()
ap.add_argument("--server", help="SMTP server to connect to")
ap.add_argument("--user", help="Username to use in SMTP AUTH")
ap.add_argument("--password", help="Password to use in SMTP AUTH")
args = ap.parse_args()

# Parse the email using the "default" policy, which is not really the default.
# If unspecified, compat32 is used, which does not support UTF8.
rawmsg = sys.stdin.buffer.read()
msg = email.parser.Parser(policy=email.policy.default).parsestr(
        rawmsg.decode('utf8'))

s = smtplib.SMTP(args.server)
s.starttls()
if args.user:
    s.login(args.user, args.password)

# Send the raw message, not parsed, because the parser does not handle some
# corner cases that well (for example, DKIM-Signature headers get mime-encoded
# incorrectly).
# Replace \n with \r\n, which is normally done by the library, but will not do
# it in this case because we are giving it bytes and not a string (which we
# cannot do because it tries to incorrectly escape the headers).
crlfmsg = re.sub(br'(?:\r\n|\n|\r(?!\n))', b"\r\n", rawmsg)

s.sendmail(
        from_addr=msg['from'], to_addrs=msg.get_all('to'),
        msg=crlfmsg,
        mail_options=['SMTPUTF8'])
s.quit()





#!/usr/bin/env python3
#
# This hacky script generates a go file with a map of version -> name for the
# entries in the TLS Cipher Suite Registry.

import csv
import urllib.request
import sys

# Where to get the TLS parameters from.
# See http://www.iana.org/assignments/tls-parameters/tls-parameters.xml.
URL = "https://www.iana.org/assignments/tls-parameters/tls-parameters-4.csv"


def getCiphers():
	req = urllib.request.urlopen(URL)
	data = req.read().decode('utf-8')

	ciphers = []
	reader = csv.DictReader(data.splitlines())
	for row in reader:
		desc = row["Description"]
		rawval = row["Value"]

		# Just plain TLS values for now, to keep it simple.
		if "-" in rawval or not desc.startswith("TLS"):
			continue

		rv1, rv2 = rawval.split(",")
		rv1, rv2 = int(rv1, 16), int(rv2, 16)

		val = "0x%02x%02x" % (rv1, rv2)
		ciphers.append((val, desc))

	return ciphers


ciphers = getCiphers()

out = open(sys.argv[1], 'w')
out.write("""\
package tlsconst

// AUTOGENERATED - DO NOT EDIT
//
// This file was autogenerated by generate-ciphers.py.

var cipherSuiteName = map[uint16]string{
""")

for ver, desc in ciphers:
	out.write('\t%s: "%s",\n' % (ver, desc))

out.write('}\n')
